@@ -4,6 +4,7 @@ class DetailedStatusCodes:
 	EXPIRED = "Expired"
 	UNDELIVERED = "Undelivered"
 	UNKNOWN_ERROR = "UnknownError"
+	OTHER_ERROR = "OtherError"
 	REJECTED = "Rejected"
 	UNKNOWN_SUBSCRIBER = "UnknownSubscriber"
 	SUBSCRIBER_UNAVAILABLE = "SubscriberUnavailable"
@@ -18,3 +19,14 @@ class DetailedStatusCodes:
 	ONE_TIME_PASSWORD_EXPIRED = "OneTimePasswordExpired"
 	ONE_TIME_PASSWORD_FAILED = "OneTimePasswordFailed"
 	SUBSCRIBER_TOO_YOUNG = "SubscriberTooYoung"
+	TIMEOUT_ERROR = "TimeoutError"
+	PENDING = "Pending"
+	TEMPORARY_ERROR = "TemporaryError"
+	MISSING_PREAUTH = "MissingPreAuth"
+	MISSING_DELIVERY_REPORT = "MissingDeliveryReport"
+	USER_IN_TRANSACTION = "UserInTransaction"
+	CONNECTION_OFFLINE = "ConnectionOffline"
+	INVALID_CREDENTIALS = "InvalidCredentials"
+	INVALID_OTP = "InvalidOtp"
+	CARD_PSP_ERROR = "CardPspError"
+	MNO_ERROR = "MnoError"
\ No newline at end of file
