@@ -17,6 +17,9 @@ class OneClickConfig(Model):
             'isRestricted',
             'invoiceText',
             'price',
+            'subscriptionPrice',
+            'subscriptionInterval',
+            'subscriptionStartSms',
             'timeout',
             'created',
             'lastModified',
